"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from ..shared import bpstier as shared_bpstier
from dataclasses_json import Undefined, dataclass_json
from orb import utils


@dataclass_json(undefined=Undefined.EXCLUDE)

@dataclasses.dataclass
class TieredBpsConfig:
    tiers: list[shared_bpstier.BpsTier] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('tiers') }})
    r"""Tiers for a Graduated BPS pricing model, where usage is bucketed into specified tiers"""
    

